==> nocc-1.8.1.tbz: www/nocc/lang/lb.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: lb.php 1925 2009-07-01 17:49:51Z siebrand $
 */

/** Luxembourgish (Lëtzebuergesch)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Robby
 */

$lang_locale = 'lb_LB.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_passwd_empty = 'D\'Këscht mam Passwuert ass eidel';
$alt_delete = 'Den erausgesichte Message läschen';
$alt_delete_one = 'De Message läschen';
$alt_new_msg = 'Nei Messagen';
$alt_reply = 'Dem Auteur äntwerten';
$alt_reply_all = 'Jidferengem äntwerten';
$alt_forward = 'Viruleeden';
$alt_next = 'Nächst';
$alt_prev = 'Vireg';
$title_next_page = 'Nächst Säit';
$title_prev_page = 'Vireg Säit';
$title_next_msg = 'Nächste Message';
$title_prev_msg = 'Virege Message';
$html_on = 'op';
$html_theme_label = 'Thema:';
$html_welcome = 'Wëllkomm op %1$s';
$html_passwd = 'Passwuert';
$html_help = 'Hëllef';
$html_server = 'Server';
$html_retry = 'Nach eng Kéier probéieren';
$html_remember = 'Astellunge verhalen';
$html_lang_label = 'Sprooch:';
$html_msgperpage_label = 'Message pro Säit:';
$html_preferences = 'Astellungen';
$html_full_name_label = 'Ganzen Numm:';
$html_email_address_label = 'E-Mailadress:';
$html_hide_addresses = 'Adresse verstoppen';
$html_use_signature = 'Ënnerschrëft benotzen';
$html_signature = 'Ënnerschrëft';
$html_signature_label = 'Ënnerschrëft:';
$html_prefs_updated = 'Astellungen aktualiséiert';
$html_manage_filters_link = 'E-Mail-Filtere geréieren';
$html_use_graphical_smilies = 'Grafesch Smilie benotzen';
$html_colored_quotes = 'Farweg Zitater';
$html_send_html_mail = 'E-Mail am HTML-Format schécken';
$html_folder_rename = 'Ëmbenennen';
$html_folder_delete = 'Läschen';
$html_folder_to = 'op';
$html_filter_remove = 'Läschen';
$html_filter_subject = 'Sujet vum Message';
$html_filter_change_tip = 'Fir e Filter z\'änneren iwwerschreiwt en einfach';
$html_reapply_filters = 'All filteren nach emol uwenden';
$html_filter_name = 'Numm vum Filter';
$html_filter_moveto = 'Réckelen op';
$html_select_one = '--Een eraussichen--';
$html_and = 'An';
$html_new_msg_in = 'Nei Messagen an';
$html_or = 'oder';
$html_move = 'Réckelen';
$html_copy = 'Kopéieren';
$html_gotopage = 'Op d\'Säit goen';
$html_page = 'Säit';
$html_of = 'vu(n)';
$html_new_msg = 'Schreiwen';
$html_reply = 'Äntwerten';
$html_reply_all = 'Jidferengem äntwerten';
$html_forward = 'Viruleeden';
$html_delete = 'Làschen';
$html_new = 'Nei';
$html_mark = 'Läschen';
$html_att_unknown = '[onbekannt]';
$html_attach_delete = 'Déi Erausgesichten ewechhuelen';
$html_attach_none = 'Dir musst e Fichier eraussiche fir drunzehänken!';
$html_sort_by = 'Sortéieren no';
$html_sort = 'Sortéieren';
$html_from = 'Vum';
$html_from_label = 'Vum:';
$html_subject = 'Sujet';
$html_subject_label = 'Objet:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent = 'Geschéckt:';
$html_wrote = 'huet geschriwwen';
$html_size = 'Gréisst';
$html_totalsize = 'Gesamtgréisst';
$html_bytes = 'Byten';
$html_filename = 'Numm vum Fichier';
$html_nosubject = 'Kee Sujet';
$html_send = 'Schécken';
$html_cancel = 'Ofbriechen';
$html_no_mail = 'Kee Message';
$html_msg = 'Message';
$html_msgs = 'Messagen';
$html_configuration = 'Dëse Server ass net gutt agestallt!';
$html_priority = 'Prioritéit';
$html_priority_label = 'Prioritéit:';
$html_lowest = 'Minimal';
$html_low = 'Niddreg';
$html_normal = 'Normal';
$html_high = 'Héich';
$html_highest = 'Maximal';
$html_receipt = 'Eng Confirmatioun vum Liese froen';
$html_select = 'Eraussichen';
$html_select_all = 'Auswiel ëmdréinen';
$html_loading_image = 'Luede vum Bild';
$html_error_occurred = 'Et ass e Feeler geschitt';
$html_wrap_none = 'Keen Zeilenëmbroch';
$html_mark_as = 'Markéieren als';
$html_read = 'geliest';
$html_unread = 'net geliest';
$html_add = 'Derbäisetzen';
$html_contacts = 'Kontakten';
$html_modify = 'Änneren';
$html_back = 'Zréck';
$html_contact_first = 'Virnumm';
$html_contact_last = 'Familjenumm';
$html_contact_nick = 'Spëtznumm';
$html_contact_mail = 'E-Mailadress';
$html_contact_list = 'Kontakt-Lëscht vum %1$s';
$html_contact_del = 'vun der Kontaktlëscht';
$html_contact_count = '%1$d Kontakten';
$html_contact_none = 'Et konnte keng Kontakte fonnt ginn.';
$html_del_msg = 'Den erausgesichte Message läschen?';
$html_down_mail = 'Eroflueden';
$original_msg = '-- Originale Message --';
$html_images_display = 'Biller weisen';
$html_smtp_error_no_conn = 'D\'SMTP Verbindung konnt net opgemaach ginn';
$html_smtp_error_unexpected = 'Onerwarten SMTP-Äntwert:';
$lang_could_not_connect = 'De Server konnt net erreecht ginn';
$lang_invalid_msg_num = 'Falsche Nummer vum Messsage';
$html_invalid_email_address = 'Net valabel e-Mailadress';
$html_seperate_msg_win = 'Messagen a separate Fënsteren';
$lang_err_send_delay = 'Dir musst tëschent 2 Maile waarden (%1$d Sekonnen)';
$html_search = 'Sichen';

==> nocc-1.8.3.tbz: www/nocc/lang/lb.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: lb.php 2164 2010-04-05 12:50:59Z gerundt $
 */

/** Luxembourgish (Lëtzebuergesch)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Robby
 */

$lang_locale = 'lb_LB.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_passwd_empty = 'D\'Këscht mam Passwuert ass eidel';
$alt_delete = 'Den erausgesichte Message läschen';
$alt_delete_one = 'De Message läschen';
$alt_new_msg = 'Nei Messagen';
$alt_reply = 'Dem Auteur äntwerten';
$alt_reply_all = 'Jidferengem äntwerten';
$alt_forward = 'Viruleeden';
$alt_next = 'Nächst';
$alt_prev = 'Vireg';
$title_next_page = 'Nächst Säit';
$title_prev_page = 'Vireg Säit';
$title_next_msg = 'Nächste Message';
$title_prev_msg = 'Virege Message';
$html_theme_label = 'Thema:';
$html_welcome = 'Wëllkomm op %1$s';
$html_login = 'Aloggen';
$html_help = 'Hëllef';
$html_wrong = 'De Benotzernumm oder d\'Passwuert sinn net richteg';
$html_retry = 'Nach eng Kéier probéieren';
$html_remember = 'Astellunge verhalen';
$html_lang_label = 'Sprooch:';
$html_msgperpage_label = 'Message pro Säit:';
$html_preferences = 'Astellungen';
$html_full_name_label = 'Ganzen Numm:';
$html_email_address_label = 'E-Mailadress:';
$html_hide_addresses = 'Adresse verstoppen';
$html_use_signature = 'Ënnerschrëft benotzen';
$html_signature = 'Ënnerschrëft';
$html_signature_label = 'Ënnerschrëft:';
$html_prefs_updated = 'Astellungen aktualiséiert';
$html_manage_filters_link = 'E-Mail-Filtere geréieren';
$html_use_graphical_smilies = 'Grafesch Smilie benotzen';
$html_colored_quotes = 'Farweg Zitater';
$html_display_struct = 'Strukturéierten Text weisen';
$html_send_html_mail = 'E-Mail am HTML-Format schécken';
$html_folder_rename = 'Ëmbenennen';
$html_folder_delete = 'Läschen';
$html_folder_to = 'op';
$html_filter_remove = 'Läschen';
$html_filter_subject = 'Sujet vum Message';
$html_filter_change_tip = 'Fir e Filter z\'änneren iwwerschreiwt en einfach';
$html_reapply_filters = 'All filteren nach emol uwenden';
$html_filter_name = 'Numm vum Filter';
$html_filter_moveto = 'Réckelen op';
$html_select_one = '--Een eraussichen--';
$html_and = 'An';
$html_new_msg_in = 'Nei Messagen an';
$html_or = 'oder';
$html_move = 'Réckelen';
$html_copy = 'Kopéieren';
$html_gotopage = 'Op d\'Säit goen';
$html_page = 'Säit';
$html_of = 'vu(n)';
$html_new_msg = 'Schreiwen';
$html_reply = 'Äntwerten';
$html_reply_all = 'Jidferengem äntwerten';
$html_forward = 'Viruleeden';
$html_delete = 'Làschen';
$html_new = 'Nei';
$html_mark = 'Läschen';
$html_unknown = '[onbekannt]';
$html_attach_delete = 'Déi Erausgesichten ewechhuelen';
$html_attach_none = 'Dir musst e Fichier eraussiche fir drunzehänken!';
$html_sort_by = 'Sortéieren no';
$html_sort = 'Sortéieren';
$html_from = 'Vum';
$html_from_label = 'Vum:';
$html_subject = 'Sujet';
$html_subject_label = 'Objet:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Geschéckt:';
$html_wrote = 'huet geschriwwen';
$html_size = 'Gréisst';
$html_totalsize = 'Gesamtgréisst';
$html_bytes = 'Byten';
$html_filename = 'Numm vum Fichier';
$html_nosubject = 'Kee Sujet';
$html_send = 'Schécken';
$html_cancel = 'Ofbriechen';
$html_no_mail = 'Kee Message';
$html_msg = 'Message';
$html_msgs = 'Messagen';
$html_configuration = 'Dëse Server ass net gutt agestallt!';
$html_priority = 'Prioritéit';
$html_priority_label = 'Prioritéit:';
$html_lowest = 'Minimal';
$html_low = 'Niddreg';
$html_normal = 'Normal';
$html_high = 'Héich';
$html_highest = 'Maximal';
$html_receipt = 'Eng Confirmatioun vum Liese froen';
$html_select = 'Eraussichen';
$html_select_all = 'Auswiel ëmdréinen';
$html_loading_image = 'Luede vum Bild';
$html_error_occurred = 'Et ass e Feeler geschitt';
$html_wrap_none = 'Keen Zeilenëmbroch';
$html_mark_as = 'Markéieren als';
$html_read = 'geliest';
$html_unread = 'net geliest';
$html_add = 'Derbäisetzen';
$html_contacts = 'Kontakten';
$html_modify = 'Änneren';
$html_back = 'Zréck';
$html_contact_first = 'Virnumm';
$html_contact_last = 'Familjenumm';
$html_contact_nick = 'Spëtznumm';
$html_contact_mail = 'E-Mailadress';
$html_contact_list = 'Kontakt-Lëscht vum %1$s';
$html_contact_del = 'vun der Kontaktlëscht';
$html_contact_count = '%1$d Kontakten';
$html_contact_none = 'Et konnte keng Kontakte fonnt ginn.';
$html_del_msg = 'Den erausgesichte Message läschen?';
$html_down_mail = 'Eroflueden';
$original_msg = '-- Originale Message --';
$html_images_display = 'Biller weisen';
$html_smtp_error_no_conn = 'D\'SMTP Verbindung konnt net opgemaach ginn';
$html_smtp_error_unexpected = 'Onerwarten SMTP-Äntwert:';
$lang_could_not_connect = 'De Server konnt net erreecht ginn';
$lang_invalid_msg_num = 'Falsche Nummer vum Messsage';
$html_invalid_email_address = 'Net valabel e-Mailadress';
$html_seperate_msg_win = 'Messagen a separate Fënsteren';
$lang_err_send_delay = 'Dir musst tëschent 2 Maile waarden (%1$d Sekonnen)';
$html_search = 'Sichen';
